==> customer-link-project-api-0.0.71-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app81279/dto/resultData/ZrysSavePrizeDataDto.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app81279.dto.resultData;

/**
 * Description:
 * <p>
 * date: 2022/11/1 16:23
 *
 * @author huakai
 */
public class ZrysSavePrizeDataDto {
    /**
     * GratefulMonth22
     * 固定值
     * 必填
     */
    private String activityCode;
    /**
     * 感恩月活动22
     * 固定值
     * 必填
     */
    private String activityDesc;
    /**
     * 手机号
     * 必填
     */
    private String contactTel;
    /**
     * 中奖信息
     */
    private String prizeInfo;
    /**
     * 系统来源
     * ZYT(掌e通)/APP(掌上中意)
     */
    private String systemSrc;
    /**
     * 免登中的userCode
     * 掌E通代理人号
     */
    private String userCode;
    /**
     * 奖品等级
     * 1为1等奖 2为2等奖
     */
    private String prizeLevel;
    /**
     * 奖品类型
     * 实物-A 虚拟-B 赠险-C
     */
    private String prizeType;

    public String getActivityCode() {
        return activityCode;
    }

    public ZrysSavePrizeDataDto setActivityCode(String activityCode) {
        this.activityCode = activityCode;
        return this;
    }

    public String getActivityDesc() {
        return activityDesc;
    }

    public ZrysSavePrizeDataDto setActivityDesc(String activityDesc) {
        this.activityDesc = activityDesc;
        return this;
    }

    public String getContactTel() {
        return contactTel;
    }

    public ZrysSavePrizeDataDto setContactTel(String contactTel) {
        this.contactTel = contactTel;
        return this;
    }

    public String getPrizeInfo() {
        return prizeInfo;
    }

    public ZrysSavePrizeDataDto setPrizeInfo(String prizeInfo) {
        this.prizeInfo = prizeInfo;
        return this;
    }

    public String getSystemSrc() {
        return systemSrc;
    }

    public ZrysSavePrizeDataDto setSystemSrc(String systemSrc) {
        this.systemSrc = systemSrc;
        return this;
    }

    public String getUserCode() {
        return userCode;
    }

    public ZrysSavePrizeDataDto setUserCode(String userCode) {
        this.userCode = userCode;
        return this;
    }

    public String getPrizeLevel() {
        return prizeLevel;
    }

    public ZrysSavePrizeDataDto setPrizeLevel(String prizeLevel) {
        this.prizeLevel = prizeLevel;
        return this;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public ZrysSavePrizeDataDto setPrizeType(String prizeType) {
        this.prizeType = prizeType;
        return this;
    }
}

==> customer-link-project-api-0.0.92-20230712.031723-6-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app81279/dto/resultData/ZrysSavePrizeDataDto.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app81279.dto.resultData;

/**
 * Description:
 * <p>
 * date: 2022/11/1 16:23
 *
 * @author huakai
 */
public class ZrysSavePrizeDataDto {
    /**
     * GCHomeland23
     * 固定值
     * 必填
     */
    private String activityCode;
    /**
     * 中意家园23
     * 固定值
     * 必填
     */
    private String activityDesc;
    /**
     * 客户id——必填
     *
     */
    private String customerId;
    /**
     * 中奖信息
     */
    private String prizeInfo;
    /**
     * 系统来源
     * ZYT(掌e通)/APP(掌上中意)
     */
    private String systemSrc;
    /**
     * ZYT(掌e通)/APP(掌上中意)/WX(微信小程序)，接口1中携带的systemSrc字段值
     * 掌E通代理人号
     */
    private String userCode;
    /**
     * 奖品等级
     * 1为1等奖 2为2等奖
     */
    private String prizeLevel;
    /**
     * 奖品类型
     * 实物-A 虚拟-B 赠险-C
     */
    private String prizeType;

    public String getActivityCode() {
        return activityCode;
    }

    public ZrysSavePrizeDataDto setActivityCode(String activityCode) {
        this.activityCode = activityCode;
        return this;
    }

    public String getActivityDesc() {
        return activityDesc;
    }

    public ZrysSavePrizeDataDto setActivityDesc(String activityDesc) {
        this.activityDesc = activityDesc;
        return this;
    }

    public String getPrizeInfo() {
        return prizeInfo;
    }

    public ZrysSavePrizeDataDto setPrizeInfo(String prizeInfo) {
        this.prizeInfo = prizeInfo;
        return this;
    }

    public String getSystemSrc() {
        return systemSrc;
    }

    public ZrysSavePrizeDataDto setSystemSrc(String systemSrc) {
        this.systemSrc = systemSrc;
        return this;
    }

    public String getUserCode() {
        return userCode;
    }

    public ZrysSavePrizeDataDto setUserCode(String userCode) {
        this.userCode = userCode;
        return this;
    }

    public String getPrizeLevel() {
        return prizeLevel;
    }

    public ZrysSavePrizeDataDto setPrizeLevel(String prizeLevel) {
        this.prizeLevel = prizeLevel;
        return this;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public ZrysSavePrizeDataDto setPrizeType(String prizeType) {
        this.prizeType = prizeType;
        return this;
    }

    public String getCustomerId() {
        return customerId;
    }

    public void setCustomerId(String customerId) {
        this.customerId = customerId;
    }
}
